Struct rustyms::error::CustomError
source · pub struct CustomError { /* private fields */ }Expand description
An error
Implementations
sourceimpl CustomError
impl CustomError
sourcepub fn error(
short_desc: impl ToString,
long_desc: impl ToString,
context: Context
) -> Self
pub fn error( short_desc: impl ToString, long_desc: impl ToString, context: Context ) -> Self
Create a new CustomError
Arguments
short_desc- A short description of the error, generally used as title linelong_desc- A longer description of the error, presented below the context to give more information and helpful feedbackcontext- The context, in the most general sense this produces output which leads the user to the right place in the code or file
sourcepub fn warning(
short_desc: impl ToString,
long_desc: impl ToString,
context: Context
) -> Self
pub fn warning( short_desc: impl ToString, long_desc: impl ToString, context: Context ) -> Self
Create a new CustomError
Arguments
short_desc- A short description of the error, generally used as title linelong_desc- A longer description of the error, presented below the context to give more information and helpful feedbackcontext- The context, in the most general sense this produces output which leads the user to the right place in the code or file
sourcepub const fn is_warning(&self) -> bool
pub const fn is_warning(&self) -> bool
Tests if this errors is a warning
sourcepub fn short_description(&self) -> &str
pub fn short_description(&self) -> &str
Gives the short description or title for this error
sourcepub fn long_description(&self) -> &str
pub fn long_description(&self) -> &str
Gives the long description for this error
sourcepub fn with_long_description(&self, long_desc: impl ToString) -> Self
pub fn with_long_description(&self, long_desc: impl ToString) -> Self
Create a copy of the error with a new long description
sourcepub fn with_context(&self, context: Context) -> Self
pub fn with_context(&self, context: Context) -> Self
Create a copy of the error with a new context
sourcepub fn overwrite_line_number(&self, line_number: usize) -> Self
pub fn overwrite_line_number(&self, line_number: usize) -> Self
Overwrite the line number with the given number, if applicable