Read in the annotations from peptide identification sources

Structs

  • A single parsed line of a fasta file
  • A peptide that is identified by a de novo or database matching program
  • An iterator returning parsed identified peptides
  • A single parsed Novor line
  • The file format for any peaks format, determining the existence and location of all possible columns
  • A single parsed line of an Opair file
  • The file format for any opair format, determining the existence and location of all possible columns
  • A single parsed line of a peaks file
  • The file format for any peaks format, determining the existence and location of all possible columns
  • The scans identifier for a peaks identification

Enums

Constants

  • Version Ab of PEAKS export
  • denovo: # id, scanNum, RT, mz(data), z, pepMass(denovo), err(data-denovo), ppm(1e6*err/(mz*z)), score, peptide, aaScore,
  • PSM: #id, spectraId, scanNum, RT, mz, z, pepMass, err, ppm, score, protein, start, length, origin, peptide, noPTMPeptide, aac, allProteins
  • An older version of a PEAKS export
  • The older supported format for denovo.csv files from Novor
  • The older supported format for psms.csv files from Novor
  • The only supported format for Opair data
  • Version X of PEAKS export (made for build 31 january 2019)
  • Version 11 of PEAKS export
  • Version X+ of PEAKS export (made for build 20 november 2019)

Traits

Type Aliases