Module rustyms::model

source ·
Handle model instantiation.

Structs

  • A model for the fragmentation, allowing control over what theoretical fragments to generate.
  • A struct to handle all possible fragments that could be generated on a single location

Enums

  • A location, or range of locations where an ion can be generated