Enum rustyms::modification::Modification
source · pub enum Modification {
Mass(Mass),
Formula(MolecularFormula),
Glycan(Vec<(MonoSaccharide, isize)>),
GlycanStructure(GlycanStructure),
Predefined(MolecularFormula, Vec<PlacementRule>, Ontology, String, usize),
Gno(GnoComposition, String),
}Expand description
A modification on an amino acid
Variants
Mass(Mass)
A modification defined with a monoisotopic mass shift
Formula(MolecularFormula)
A modification defined with a molecular formula
Glycan(Vec<(MonoSaccharide, isize)>)
A glycan without a defined structure
GlycanStructure(GlycanStructure)
A glycan with a defined structure
Predefined(MolecularFormula, Vec<PlacementRule>, Ontology, String, usize)
A modification from one of the modification ontologies
Gno(GnoComposition, String)
A modification from one of the modification ontologies
Implementations
sourceimpl Modification
impl Modification
sourcepub fn try_from(
line: &str,
range: Range<usize>,
lookup: &mut Vec<(Option<String>, Option<Self>)>
) -> Result<ReturnModification, CustomError>
pub fn try_from( line: &str, range: Range<usize>, lookup: &mut Vec<(Option<String>, Option<Self>)> ) -> Result<ReturnModification, CustomError>
Try to parse the modification. Any ambiguous modification will be number according to the lookup (which may be added to if necessary). The result is the modification, with, if applicable, its determined ambiguous group.
Errors
If it is not a valid modification return a CustomError explaining the error.
sourcepub fn sloppy_modification(line: &str, location: Range<usize>) -> Option<Self>
pub fn sloppy_modification(line: &str, location: Range<usize>) -> Option<Self>
Parse a modification defined by sloppy names
sourcepub fn is_possible(
&self,
seq: &SequenceElement,
index: usize,
length: usize
) -> bool
pub fn is_possible( &self, seq: &SequenceElement, index: usize, length: usize ) -> bool
Check to see if this modification can be placed on the specified element