CompoundPeptidoformIon

Struct CompoundPeptidoformIon 

pub struct CompoundPeptidoformIon(/* private fields */);
A single full ProForma entry. This entry can contain multiple sets of cross-linked peptides. A single set of cross-linked peptides is a PeptidoformIon. A ProForma entry with two chimeric peptides will be saved as one CompoundPeptidoformIon with two PeptidoformIons that each contain one of the Peptidoforms.

Implementations

Source

impl CompoundPeptidoformIon

pub fn new(iter: impl IntoIterator<Item = PeptidoformIon>) -> Option<Self>

Create a new CompoundPeptidoformIon from many Peptidoforms. This returns None if the global isotope modifications of all peptidoforms are not identical.

pub fn formulas(&self) -> Multi<MolecularFormula>

Get all possible formulas for this compound peptidoform

pub fn singular(self) -> Option<PeptidoformIon>

Assume there is exactly one peptidoform in this compound peptidoform.

pub fn singular_ref(&self) -> Option<&PeptidoformIon>

Assume there is exactly one peptidoform in this compound peptidoform.

pub fn singular_peptidoform(self) -> Option<Peptidoform<Linked>>

Assume there is exactly one peptide in this compound peptidoform.

pub fn singular_peptidoform_ref(&self) -> Option<&Peptidoform<Linked>>

Assume there is exactly one peptide in this compound peptidoform.

pub fn peptidoform_ions(&self) -> &[PeptidoformIon]

Get all peptidoform ions making up this compound peptidoform.

pub fn peptidoforms(&self) -> impl Iterator<Item = &Peptidoform<Linked>>

Get all peptidoforms making up this compound peptidoform.

pub fn generate_theoretical_fragments( &self, max_charge: Charge, model: &FragmentationModel, ) -> Vec<Fragment>

Generate the theoretical fragments for this compound peptidoform.

pub fn display( &self, f: &mut impl Write, specification_compliant: bool, ) -> Result

Display this compound peptidoform. specification_compliant Displays this compound peptidoform either normalised to the internal representation (with false) or as fully spec compliant ProForma (no glycan structure or custom modifications) (with true).

Errors

Only if the underlying formatter (f) errors.

Source

impl CompoundPeptidoformIon

pub fn pro_forma<'a>( value: &'a str, custom_database: Option<&CustomDatabase>, ) -> Result<Self, BoxedError<'a, BasicKind>>

Parse a compound peptidoform in the ProForma specification.

Errors

It fails when the string is not a valid ProForma string.