pub struct Model {
pub a: (Location, Vec<NeutralLoss>),
pub b: (Location, Vec<NeutralLoss>),
pub c: (Location, Vec<NeutralLoss>),
pub d: (Location, Vec<NeutralLoss>),
pub v: (Location, Vec<NeutralLoss>),
pub w: (Location, Vec<NeutralLoss>),
pub x: (Location, Vec<NeutralLoss>),
pub y: (Location, Vec<NeutralLoss>),
pub z: (Location, Vec<NeutralLoss>),
pub precursor: Vec<NeutralLoss>,
pub ppm: MassOverCharge,
pub glycan_fragmentation: Option<Vec<NeutralLoss>>,
}Expand description
A model for the fragmentation, allowing control over what theoretical fragments to generate.
Fields
a: (Location, Vec<NeutralLoss>)a series ions
b: (Location, Vec<NeutralLoss>)b series ions
c: (Location, Vec<NeutralLoss>)c series ions
d: (Location, Vec<NeutralLoss>)d series ions (side chain fragmentation from a)
v: (Location, Vec<NeutralLoss>)v series ions (full side chain broken off)
w: (Location, Vec<NeutralLoss>)w series ions (side chain fragmentation from z)
x: (Location, Vec<NeutralLoss>)x series ions
y: (Location, Vec<NeutralLoss>)y series ions
z: (Location, Vec<NeutralLoss>)z series ions
precursor: Vec<NeutralLoss>precursor ions
ppm: MassOverChargeThe matching tolerance
glycan_fragmentation: Option<Vec<NeutralLoss>>If some search for glycan with the given neutral losses
Implementations
sourceimpl Model
impl Model
sourcepub fn ions(&self, index: usize, length: usize) -> PossibleIons<'_>
pub fn ions(&self, index: usize, length: usize) -> PossibleIons<'_>
Give all possible ions for the given position
sourcepub fn new(
a: (Location, Vec<NeutralLoss>),
b: (Location, Vec<NeutralLoss>),
c: (Location, Vec<NeutralLoss>),
d: (Location, Vec<NeutralLoss>),
v: (Location, Vec<NeutralLoss>),
w: (Location, Vec<NeutralLoss>),
x: (Location, Vec<NeutralLoss>),
y: (Location, Vec<NeutralLoss>),
z: (Location, Vec<NeutralLoss>),
precursor: Vec<NeutralLoss>,
ppm: MassOverCharge,
glycan_fragmentation: Option<Vec<NeutralLoss>>
) -> Self
pub fn new( a: (Location, Vec<NeutralLoss>), b: (Location, Vec<NeutralLoss>), c: (Location, Vec<NeutralLoss>), d: (Location, Vec<NeutralLoss>), v: (Location, Vec<NeutralLoss>), w: (Location, Vec<NeutralLoss>), x: (Location, Vec<NeutralLoss>), y: (Location, Vec<NeutralLoss>), z: (Location, Vec<NeutralLoss>), precursor: Vec<NeutralLoss>, ppm: MassOverCharge, glycan_fragmentation: Option<Vec<NeutralLoss>> ) -> Self
Build a new model