pub struct CompoundPeptidoformIon(/* private fields */);Expand description
A single full ProForma entry. This entry can contain multiple sets of cross-linked peptides.
A single set of cross-linked peptides is a PeptidoformIon. A ProForma entry with two chimeric
peptides will be saved as one CompoundPeptidoformIon with two PeptidoformIons that each
contain one of the Peptidoforms.
Implementations
Sourceimpl CompoundPeptidoformIon
impl CompoundPeptidoformIon
Sourcepub fn new(iter: impl IntoIterator<Item = PeptidoformIon>) -> Option<Self>
pub fn new(iter: impl IntoIterator<Item = PeptidoformIon>) -> Option<Self>
Create a new CompoundPeptidoformIon from many Peptidoforms. This returns None if the
global isotope modifications of all peptidoforms are not identical.
Sourcepub fn formulas(&self) -> Multi<MolecularFormula>
pub fn formulas(&self) -> Multi<MolecularFormula>
Get all possible formulas for this compound peptidoform
Sourcepub fn singular(self) -> Option<PeptidoformIon>
pub fn singular(self) -> Option<PeptidoformIon>
Assume there is exactly one peptidoform in this compound peptidoform.
Sourcepub fn singular_ref(&self) -> Option<&PeptidoformIon>
pub fn singular_ref(&self) -> Option<&PeptidoformIon>
Assume there is exactly one peptidoform in this compound peptidoform.
Sourcepub fn singular_peptidoform(self) -> Option<Peptidoform<Linked>>
pub fn singular_peptidoform(self) -> Option<Peptidoform<Linked>>
Assume there is exactly one peptide in this compound peptidoform.
Sourcepub fn singular_peptidoform_ref(&self) -> Option<&Peptidoform<Linked>>
pub fn singular_peptidoform_ref(&self) -> Option<&Peptidoform<Linked>>
Assume there is exactly one peptide in this compound peptidoform.
Sourcepub fn peptidoform_ions(&self) -> &[PeptidoformIon]
pub fn peptidoform_ions(&self) -> &[PeptidoformIon]
Get all peptidoform ions making up this compound peptidoform.
Sourcepub fn peptidoforms(&self) -> impl Iterator<Item = &Peptidoform<Linked>>
pub fn peptidoforms(&self) -> impl Iterator<Item = &Peptidoform<Linked>>
Get all peptidoforms making up this compound peptidoform.
Sourcepub fn generate_theoretical_fragments(
&self,
max_charge: Charge,
model: &FragmentationModel,
) -> Vec<Fragment>
pub fn generate_theoretical_fragments( &self, max_charge: Charge, model: &FragmentationModel, ) -> Vec<Fragment>
Generate the theoretical fragments for this compound peptidoform.
Sourcepub fn display(
&self,
f: &mut impl Write,
specification_compliant: bool,
) -> Result
pub fn display( &self, f: &mut impl Write, specification_compliant: bool, ) -> Result
Display this compound peptidoform.
specification_compliant Displays this compound peptidoform either normalised to the
internal representation (with false) or as fully spec compliant ProForma (no glycan
structure or custom modifications) (with true).
Errors
Only if the underlying formatter (f) errors.
Sourceimpl CompoundPeptidoformIon
impl CompoundPeptidoformIon
Sourcepub fn pro_forma<'a>(
value: &'a str,
custom_database: Option<&CustomDatabase>,
) -> Result<Self, BoxedError<'a, BasicKind>>
pub fn pro_forma<'a>( value: &'a str, custom_database: Option<&CustomDatabase>, ) -> Result<Self, BoxedError<'a, BasicKind>>
Parse a compound peptidoform in the ProForma specification.
Errors
It fails when the string is not a valid ProForma string.